[![Documentation Status](https://readthedocs.org/projects/gettsim/badge/?version=latest)](https://gettsim.readthedocs.io/latest)
![PyPI - Version](https://img.shields.io/pypi/v/gettsim)
[![image](https://img.shields.io/conda/pn/conda-forge/gettsim.svg)](https://anaconda.org/conda-forge/gettsim)
[![main](https://github.com/ttsim-dev/gettsim/actions/workflows/main.yaml/badge.svg)](https://github.com/ttsim-dev/gettsim/actions/workflows/main.yaml)
[![image](https://codecov.io/gh/ttsim-dev/gettsim/branch/main/graph/badge.svg)](https://codecov.io/gh/ttsim-dev/gettsim)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/ttsim-dev/gettsim/main.svg)](https://results.pre-commit.ci/latest/github/ttsim-dev/gettsim/main)
[![image](https://img.shields.io/github/contributors/ttsim-dev/gettsim.svg)](https://github.com/ttsim-dev/gettsim/graphs/contributors)
[![image](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![image](https://img.shields.io/badge/zulip-join_chat-brightgreen.svg)](https://gettsim.zulipchat.com)

<p align="center">
   <br>
   <br>
   <a href="https://github.com/ttsim-dev/gettsim/">
      <img src="docs/_static/images/gettsim_logo_text.png" width="800" alt="GETTSIM">
   </a>
   <br>
</p>

GETTSIM provides a depiction of the German Taxes and Transfers System that is usable in
a wide array of research applications, ranging from complex dynamic programming models
to detailed microsimulation studies.

GETTSIM is implemented in Python, thereby achieving both user-friendliness and
flexibility. All features are extensively tested.

You can install GETTSIM via conda with

```shell-session
$ conda install -c conda-forge gettsim
```

The documentation is available at <https://gettsim.readthedocs.io>. If you want to use
it or help out in its development, feel free to get in touch! The ideal ways are to open
an issue if you find a bug or something does not work as expected, or by joining our
Zulip Chat at <https://gettsim.zulipchat.com>.

## Initiated by

<p align="center">
   <a href="https://www.iza.org">
      <img src="docs/_static/images/iza_logo.jpg" width="150" alt="IZA">
   </a>
   &emsp;

<a href="https://www.diw.de/">
      <img src="docs/_static/images/diw_logo.jpg" width="150" alt="DIW">
   </a>
   &emsp;

<a href="https://www.ifo.de/">
      <img src="docs/_static/images/ifo_logo.png" width="150" alt="ifo Institute">
   </a>
   &emsp;

<a href="https://www.zew.de/">
      <img src="docs/_static/images/zew_logo.png" width="150" alt="ZEW">
   </a>
   &emsp;

<a href="https://www.uni-bonn.de">
      <img src="docs/_static/images/uni_bonn_logo.png" width="150"
      alt="Universität Bonn">
   </a>
   &emsp;

<br>
   <br>

<a href="https://www.uni-kassel.de">
      <img src="docs/_static/images/uni_kassel_logo.png" width="150"
      alt="Universität Kassel">
   </a>
   &emsp;

<a href="https://www.uni-muenchen.de">
      <img src="docs/_static/images/lmu_logo.svg" width="150"
      alt="Ludwig-Maximilians-Universität München">
   </a>
   &emsp;

<a href="https://www.uni-mannheim.de">
      <img src="docs/_static/images/uni_mannheim_logo.png" width="150"
      alt="Universität Mannheim">
   </a>
   &emsp;

<a href="https://www.fu-berlin.de">
      <img src="docs/_static/images/fu_berlin_logo.svg" width="150"
      alt="Freie Universität Berlin">
   </a>
   &emsp;

<a href="https://www.iab.de/">
      <img src="docs/_static/images/iab_logo.png" width="150" alt="IAB">
   </a>
   &emsp;

</p>
